@@ -246,7 +246,8 @@ class DirectoryTemplate(ContentTemplate):
         """
         checks output for validity
         """
-        assert output # must provide output
+        if not output:
+            raise AssertionError("Must provide output")
         if os.path.exists(output):
             assert os.path.isdir(output), "%s: Must be a directory" % self.name
 
