@@ -38,7 +38,7 @@ class Unittest(MakeItSoTemplate):
     """template for python unittest"""
     templates = [('python_package', 'tests', 'test_{{package}}.py')]
     def pre(self, variables, output):
-        if 'package' not in variables:
+        if output and 'package' not in variables:
             package = os.path.splitext(os.path.basename(output.rstrip(os.path.sep)))[0]
             indicator = 'test_'
             if package.startswith(indicator):
@@ -113,9 +113,11 @@ class PythonPackageTemplate(PythonTemplate):
 
         # get package name from project
         allowable = set(string.letters + string.digits + '_')
-        if not set(variables['project']).issubset(allowable):
-            raise AssertionError("Illegal fields in package name")
-        variables['package'] = variables['project'].lower()
+        package = variables['project'].lower()
+        package = ''.join([c for c in package
+                           if c in allowable])
+        # TODO better: translation matrix
+        variables['package'] = package
 
         # name of CLI main file
         variables['main'] = 'main'
@@ -157,5 +159,6 @@ def main(args=sys.argv[1:]):
     cli = PythonPackageCLI(PythonPackageTemplate)
     cli(*args)
 
+
 if __name__ == '__main__':
     main()
